emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/info.el,v


From: Karl Fogel
Subject: [Emacs-diffs] Changes to emacs/lisp/info.el,v
Date: Fri, 07 Mar 2008 05:44:39 +0000

CVSROOT:        /cvsroot/emacs
Module name:    emacs
Changes by:     Karl Fogel <kfogel>     08/03/07 05:44:38

Index: info.el
===================================================================
RCS file: /cvsroot/emacs/emacs/lisp/info.el,v
retrieving revision 1.516
retrieving revision 1.517
diff -u -b -r1.516 -r1.517
--- info.el     7 Mar 2008 05:00:17 -0000       1.516
+++ info.el     7 Mar 2008 05:44:34 -0000       1.517
@@ -3374,7 +3374,7 @@
 (put 'Info-mode 'no-clone-indirect t)
 
 (defvar tool-bar-map)
-(defvar bookmark-make-cell-function)
+(defvar bookmark-make-record-function)
 
 ;; Autoload cookie needed by desktop.el
 ;;;###autoload
@@ -3487,8 +3487,8 @@
   (set (make-local-variable 'revert-buffer-function)
        'Info-revert-buffer-function)
   (Info-set-mode-line)
-  (set (make-local-variable 'bookmark-make-cell-function)
-       'Info-bookmark-make-cell)
+  (set (make-local-variable 'bookmark-make-record-function)
+       'Info-bookmark-make-record)
   (run-mode-hooks 'Info-mode-hook))
 
 ;; When an Info buffer is killed, make sure the associated tags buffer
@@ -4326,7 +4326,7 @@
 ;; This is only called from bookmark.el.
 (declare-function bookmark-buffer-file-name "bookmark" ())
 
-(defun Info-bookmark-make-cell (annotation &rest args)
+(defun Info-bookmark-make-record (annotation &rest args)
   (let ((the-record
          `((filename . ,(bookmark-buffer-file-name))
            (front-context-string
@@ -4368,7 +4368,7 @@
 ;;;###autoload
 (defun Info-bookmark-jump (bmk)
   ;; This implements the `handler' function interface for record type returned
   ;; by `Info-make-cell-function', which see.
   (let* ((file (expand-file-name (bookmark-get-filename bmk)))
          (forward-str            (bookmark-get-front-context-string bmk))
          (behind-str             (bookmark-get-rear-context-string bmk))
@@ -4368,7 +4368,7 @@
 (defun Info-bookmark-jump (bmk)
   ;; This implements the `handler' function interface for record type returned
-  ;; by `Info-make-cell-function', which see.
+  ;; by `Info-bookmark-make-record', which see.
   (let* ((file (expand-file-name (bookmark-get-filename bmk)))
          (forward-str            (bookmark-get-front-context-string bmk))




reply via email to

[Prev in Thread] Current Thread [Next in Thread]